@@ -257,6 +257,21 @@ class NetworkGraph:
         """Return an ``AdjacencyView`` of the graph."""
         return AdjacencyView(self._nx_graph.adj)
 
+    @property
+    def connected_components(self) -> List[set]:
+        """Return the connected components of the graph."""
+        return list(nx.connected_components(self._nx_graph))
+
+    @property
+    def number_of_nodes(self) -> int:
+        """Return the number of nodes in the graph."""
+        return self._nx_graph.number_of_nodes()
+
+    @property
+    def number_of_edges(self) -> int:
+        """Return the number of edges in the graph."""
+        return self._nx_graph.number_of_edges()
+
     def edge_subgraph(self, edges: Iterable) -> "NetworkGraph":
         """Return a subgraph containing only the specified edges.
 
@@ -441,12 +456,11 @@ class NetworkGraph:
         return ax
 
     def plot_network_components(self, *args: Any, **kwargs: Any) -> List:
-        """Plot network components (DEPRECATED).
+        """Plot network components.
 
         .. deprecated:: 0.1.0
-            This method will be removed in a future version.
-            Please use `fplot_network_components` which provides a figure-level interface
-            for plotting components.
+          `plot_network_components` will be removed in a future version.
+          Use `fplot_network_components` instead.
         """
         import warnings
 
@@ -580,7 +594,37 @@ class NetworkGraph:
         return NetworkGraph(network_G)
 
 
-def _prepare_network_graph(
+def compute_network_grid(
+    connected_components: List[set], style: StyleTemplate
+) -> Tuple[Figure, np.ndarray]:
+    """Compute the grid layout for network component subplots.
+
+    Parameters
+    ----------
+    connected_components : list[set]
+        A list of sets, where each set contains the nodes of a connected component.
+    style : StyleTemplate
+        The style template used for plotting.
+
+    Returns
+    -------
+    Tuple[Figure, np.ndarray]
+        A tuple containing the Matplotlib figure and the grid of axes.
+    """
+    n_components = len(connected_components)
+    n_cols = int(np.ceil(np.sqrt(n_components)))
+    n_rows = int(np.ceil(n_components / n_cols))
+    fig, axes_grid = plt.subplots(n_rows, n_cols, figsize=(19.2, 10.8))
+    fig = cast(Figure, fig)
+    fig.patch.set_facecolor(style.background_color)
+    if not isinstance(axes_grid, np.ndarray):
+        axes = np.array([axes_grid])
+    else:
+        axes = axes_grid.flatten()
+    return fig, axes
+
+
+def prepare_network_graph(
     pd_df: pd.DataFrame,
     source: str,
     target: str,
@@ -588,7 +632,37 @@ def _prepare_network_graph(
     sort_by: Optional[str],
     node_list: Optional[List],
 ) -> NetworkGraph:
-    """Prepare NetworkGraph for plotting."""
+    """Prepare a NetworkGraph for plotting from a pandas DataFrame.
+
+    This function takes a DataFrame and prepares it for network visualization by:
+    1. Filtering the DataFrame to include only the nodes in `node_list` (if provided).
+    2. Validating the DataFrame to ensure it has the required columns.
+    3. Creating a `NetworkGraph` from the edge list.
+    4. Extracting the k-core of the graph (k=2) to focus on the main structure.
+    5. Calculating node weights based on the sum of their top k edge weights.
+    6. Trimming the graph to keep only the top k edges per node.
+
+    Parameters
+    ----------
+    pd_df : pd.DataFrame
+        DataFrame containing the edge list.
+    source : str
+        Column name for source nodes.
+    target : str
+        Column name for target nodes.
+    weight : str
+        Column name for edge weights.
+    sort_by : str, optional
+        Column to sort the DataFrame by before processing.
+    node_list : list, optional
+        A list of nodes to include in the graph. If provided, the DataFrame
+        will be filtered to include only edges connected to these nodes.
+
+    Returns
+    -------
+    NetworkGraph
+        The prepared `NetworkGraph` object.
+    """
     if node_list:
         df = pd_df.loc[
             (pd_df["source"].isin(node_list)) | (pd_df["target"].isin(node_list))
@@ -648,12 +722,13 @@ def aplot_network(
     Axes
         Matplotlib axes with the plotted network.
     """
-    graph = _prepare_network_graph(pd_df, source, target, weight, sort_by, node_list)
+    graph = prepare_network_graph(pd_df, source, target, weight, sort_by, node_list)
     return graph.plot_network(title=title, style=style, weight=weight, ax=ax)
 
 
 def aplot_network_components(
     pd_df: pd.DataFrame,
+    axes: Optional[np.ndarray],
     source: str = "source",
     target: str = "target",
     weight: str = "weight",
@@ -662,7 +737,6 @@ def aplot_network_components(
     sort_by: Optional[str] = None,
     node_list: Optional[List] = None,
     ascending: bool = False,
-    axes: Optional[np.ndarray] = None,
 ) -> None:
     """Plot network components separately on multiple axes.
 
@@ -686,10 +760,10 @@ def aplot_network_components(
         Nodes to include.
     ascending : bool, optional
         Sort order for the data. The default is `False`.
-    axes : np.ndarray, optional
-        Existing axes to draw on. If None, new axes are created.
+    axes : np.ndarray
+        Existing axes to draw on.
     """
-    graph = _prepare_network_graph(pd_df, source, target, weight, sort_by, node_list)
+    graph = prepare_network_graph(pd_df, source, target, weight, sort_by, node_list)
 
     connected_components = list(nx.connected_components(graph._nx_graph))
 
@@ -699,37 +773,27 @@ def aplot_network_components(
                 ax.set_axis_off()
         return
 
-    if axes is None:
-        n_components = len(connected_components)
-        n_cols = int(np.ceil(np.sqrt(n_components)))
-        n_rows = int(np.ceil(n_components / n_cols))
-        fig, axes_grid = plt.subplots(n_rows, n_cols, figsize=(19.2, 10.8))
-        fig = cast(Figure, fig)
-        fig.patch.set_facecolor(style.background_color)
-        if not isinstance(axes_grid, np.ndarray):
-            axes = np.array([axes_grid])
-        else:
-            axes = axes_grid.flatten()
+    local_axes = axes
+    if local_axes is None:
+        fig, local_axes = compute_network_grid(connected_components, style)
 
     i = -1
     for i, component in enumerate(connected_components):
-        if i < len(axes):
+        if i < len(local_axes):
             if len(component) > 5:
                 component_graph = graph.subgraph(node_list=list(component))
                 component_graph.plot_network(
                     title=f"{title}::{i}" if title else str(i),
                     style=style,
                     weight=weight,
-                    ax=axes[i],
+                    ax=local_axes[i],
                 )
-            axes[i].set_axis_on()
+            local_axes[i].set_axis_on()
         else:
-            break  # Stop if there are more components than axes
+            break
 
-    # Turn off any unused axes
-    if axes is not None:
-        for j in range(i + 1, len(axes)):
-            axes[j].set_axis_off()
+    for j in range(i + 1, len(local_axes)):
+        local_axes[j].set_axis_off()
 
 
 def fplot_network(
